is_work_tree_root

Function is_work_tree_root 

pub fn is_work_tree_root(dir: &Path) -> bool
Whether dir is the root of a git work tree.

A .git that is a file rather than a directory is a linked work tree or a submodule, and is just as much a work tree root as the ordinary case.