pub enum Reset {
WorkTree,
Hard,
}Expand description
What to do about tracked files that have been changed.
Variants
WorkTree
Discard changes to tracked files in the working tree, leaving the index alone:
git restore -- ..
Hard
Discard everything, index included: git reset --hard HEAD.
Implementations