#[non_exhaustive]pub enum RuleError {
Read(PathBuf, Error),
Parse(String),
NoMarkers(String),
NoTargets(String),
DuplicateId(String),
Glob(String, String),
}Expand description
Why a ruleset could not be loaded.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Read(PathBuf, Error)
The user’s rules file could not be read.
Parse(String)
The TOML was malformed or a rule was missing a mandatory field.
NoMarkers(String)
A rule declared no markers, which would make it a bare-name match.
NoTargets(String)
A rule declared nothing to reclaim.
DuplicateId(String)
Two rules share an id, so an override would be ambiguous.
Glob(String, String)
A marker or target pattern is not a valid glob.